#include "texture.h"
#include "glassert.h"
#include <QImage>

Texture::Texture(QString filename)
{
    img = new QImage(filename);

    int bpp = (img->depth() == 32) ? GL_RGBA : GL_RGB;
    int format = (img->depth() == 32) ? GL_BGRA : GL_BGR;

    glAssert(glGenTextures(1, &texId));
    glAssert(glBindTexture(GL_TEXTURE_2D, texId));
    glAssert(glTexImage2D(GL_TEXTURE_2D, 0, bpp, img->width(), img->height(), 0, format, GL_UNSIGNED_BYTE, img->bits()));
    glAssert(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT));
    glAssert(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT));
    glAssert(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST));
    glAssert(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST));
}

Texture::~Texture()
{
    glAssert(glDeleteTextures(1, &texId));
}

void Texture::bind(int slot)
{
    GLenum texSlot = GL_TEXTURE0+slot;
    glAssert(glActiveTexture(texSlot));
    glAssert(glBindTexture(GL_TEXTURE_2D, texId));
}

